date_time_range

Function date_time_range 

pub fn date_time_range(
    value: &DateTime,
) -> Result<DateRange, InsertableIndexError>
Converts a FHIR date/time value into a date range suitable for indexing.

Errors

Returns an InsertableIndexError if the supplied year, year/month, or year/month/day value cannot be converted into a valid date range.