pub fn get_decimal_range(
value: &str,
) -> Result<DecimalRange, InsertableIndexError>Expand description
Calculates the decimal range used for indexing a number or quantity, based on the precision of the input value.
Errors
Returns InsertableIndexError::FailedDowncast if value cannot be
parsed as an f64.