to_insertable_index

Function to_insertable_index 

pub fn to_insertable_index(
    parameter: &ResolvedParameter,
    result: &[&dyn MetaValue],
) -> Result<InsertableIndex, OperationOutcomeError>
Converts resolved search parameter values into an indexable representation.

Values that cannot be converted to the corresponding index type are skipped.

Errors

Returns [OperationOutcomeError] if the search parameter has an unsupported or invalid type.